﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using Syncfusion.UI.Xaml.Grid;

namespace WpfTestingSample
{
    public partial class MainWindow
    {
        public MainWindow()
        {
            InitializeComponent();
            SampleDataGrid.AutoGeneratingColumn += SampleDataGrid_AutoGeneratingColumn;
        }

        private void SampleDataGrid_AutoGeneratingColumn(object sender, AutoGeneratingColumnArgs e)
        {
            e.Column.AllowEditing = e.Column.MappingName == "ItemType" || e.Column.MappingName == "Value";

            if (e.Column.MappingName == "ItemName" || e.Column.MappingName == "ItemShortName" || e.Column.MappingName == "ItemType")
            {
                e.Column.CellStyle = Application.Current.FindResource("DarkGrayStyle") as Style;
            }

            if (e.Column.MappingName == "Value")
            {
                e.Column.CellStyle = GetDependingStyle();
            }
        }

        private Style GetDependingStyle()
        {
            // ItemType == 1 (-> show ItemName in TextBlock)
            var factory1 = new FrameworkElementFactory(typeof(TextBlock));
            factory1.SetBinding(TextBlock.TextProperty, new Binding("ItemName"));
            factory1.SetValue(TextBlock.ForegroundProperty, Brushes.Black);
            factory1.SetValue(TextBlock.BackgroundProperty, Brushes.Aquamarine);
            var trigger1 = new DataTrigger { Binding = new Binding("ItemType"), Value = "1" };
            trigger1.Setters.Add(new Setter { Property = ContentTemplateProperty, Value = new DataTemplate { VisualTree = factory1 } });



            // ItemType == 2 (-> show ItemShortName in TextBox)
            var factory2 = new FrameworkElementFactory(typeof(TextBox));
            factory2.SetBinding(TextBox.TextProperty, new Binding("ItemShortName"));
            factory2.SetValue(TextBox.ForegroundProperty, Brushes.Black);
            factory2.SetValue(TextBox.BackgroundProperty, Brushes.Coral);
            var trigger2 = new DataTrigger { Binding = new Binding("ItemType"), Value = "2" };
            trigger2.Setters.Add(new Setter { Property = ContentTemplateProperty, Value = new DataTemplate { VisualTree = factory2 } });



            // add triggers to CellStyle
            var style = new Style(typeof(GridCell));
            style.Triggers.Add(trigger1);
            style.Triggers.Add(trigger2);
            return style;
        }
    }
}
